@@ -1,7 +1,7 @@
 /*
  *  mainwindow.cpp  -  main application window
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -20,7 +20,6 @@
 #include "resourcescalendar.h"
 #include "resourceselector.h"
 #include "templatedlg.h"
-#include "templatemenuaction.h"
 #include "templatepickdlg.h"
 #include "traywindow.h"
 #include "wakedlg.h"
@@ -57,9 +56,7 @@ using namespace KCalUtils;
 #include <KToolBarPopupAction>
 
 #include <QAction>
-#include <QLocale>
 #include <QSplitter>
-#include <QByteArray>
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QResizeEvent>
@@ -296,7 +293,7 @@ bool MainWindow::eventFilter(QObject* obj, QEvent* e)
         {
             case QEvent::KeyPress:
             {
-                auto* ke = static_cast<QKeyEvent*>(e);
+                auto ke = static_cast<QKeyEvent*>(e);
                 if (ke->key() == Qt::Key_Delete  &&  ke->modifiers() == Qt::ShiftModifier)
                 {
                     // Prevent Shift-Delete being processed by EventListDelegate
@@ -374,7 +371,7 @@ void MainWindow::showEvent(QShowEvent* se)
     mShown = true;
 
     if (mMenuError)
-        QTimer::singleShot(0, this, &MainWindow::showMenuErrorMessage);
+        QTimer::singleShot(0, this, &MainWindow::showMenuErrorMessage);    //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 }
 
 /******************************************************************************
@@ -411,22 +408,10 @@ void MainWindow::initActions()
     connect(mActionTemplates, &QAction::triggered, this, &MainWindow::slotTemplates);
 
     mActionNew = new NewAlarmAction(false, i18nc("@action", "&New"), this, actions);
+    mActionNew->setActionNames(QStringLiteral("newDisplay"), QStringLiteral("newCommand"), QStringLiteral("newEmail"), QStringLiteral("newAudio"), QStringLiteral("newFromTemplate"));
     actions->addAction(QStringLiteral("new"), mActionNew);
-
-    QAction* action = mActionNew->displayAlarmAction(QStringLiteral("newDisplay"));
-    connect(action, &QAction::triggered, this, &MainWindow::slotNewDisplay);
-
-    action = mActionNew->commandAlarmAction(QStringLiteral("newCommand"));
-    connect(action, &QAction::triggered, this, &MainWindow::slotNewCommand);
-
-    action = mActionNew->emailAlarmAction(QStringLiteral("newEmail"));
-    connect(action, &QAction::triggered, this, &MainWindow::slotNewEmail);
-
-    action = mActionNew->audioAlarmAction(QStringLiteral("newAudio"));
-    connect(action, &QAction::triggered, this, &MainWindow::slotNewAudio);
-
-    TemplateMenuAction* templateMenuAction = mActionNew->fromTemplateAlarmAction(QStringLiteral("newFromTemplate"));
-    connect(templateMenuAction, &TemplateMenuAction::selected, this, &MainWindow::slotNewFromTemplate);
+    connect(mActionNew, &NewAlarmAction::selected, this, &MainWindow::slotNew);
+    connect(mActionNew, &NewAlarmAction::selectedTemplate, this, &MainWindow::slotNewFromTemplate);
 
     mActionCreateTemplate = new QAction(i18nc("@action", "Create Tem&plate..."), this);
     actions->addAction(QStringLiteral("createTemplate"), mActionCreateTemplate);
@@ -434,12 +419,12 @@ void MainWindow::initActions()
 
     mActionCopy = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18nc("@action", "&Copy..."), this);
     actions->addAction(QStringLiteral("copy"), mActionCopy);
-    actions->setDefaultShortcut(mActionCopy, QKeySequence(Qt::SHIFT + Qt::Key_Insert));
+    actions->setDefaultShortcut(mActionCopy, QKeySequence(Qt::SHIFT | Qt::Key_Insert));
     connect(mActionCopy, &QAction::triggered, this, &MainWindow::slotCopy);
 
     mActionModify = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18nc("@action", "&Edit..."), this);
     actions->addAction(QStringLiteral("modify"), mActionModify);
-    actions->setDefaultShortcut(mActionModify, QKeySequence(Qt::CTRL + Qt::Key_E));
+    actions->setDefaultShortcut(mActionModify, QKeySequence(Qt::CTRL | Qt::Key_E));
     connect(mActionModify, &QAction::triggered, this, &MainWindow::slotModify);
 
     mActionDelete = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("@action", "&Delete"), this);
@@ -450,20 +435,20 @@ void MainWindow::initActions()
     // Set up Shift-Delete as a shortcut to delete without confirmation
     mActionDeleteForce = new QAction(i18nc("@action", "Delete Without Confirmation"), this);
     actions->addAction(QStringLiteral("delete-force"), mActionDeleteForce);
-    actions->setDefaultShortcut(mActionDeleteForce, QKeySequence::Delete + Qt::SHIFT);
+    actions->setDefaultShortcut(mActionDeleteForce, QKeySequence::Delete | Qt::SHIFT);
     connect(mActionDeleteForce, &QAction::triggered, this, &MainWindow::slotDeleteForce);
 
     mActionReactivate = new QAction(i18nc("@action", "Reac&tivate"), this);
     actions->addAction(QStringLiteral("undelete"), mActionReactivate);
-    actions->setDefaultShortcut(mActionReactivate, QKeySequence(Qt::CTRL + Qt::Key_R));
+    actions->setDefaultShortcut(mActionReactivate, QKeySequence(Qt::CTRL | Qt::Key_R));
     connect(mActionReactivate, &QAction::triggered, this, &MainWindow::slotReactivate);
 
     mActionEnable = new QAction(this);
     actions->addAction(QStringLiteral("disable"), mActionEnable);
-    actions->setDefaultShortcut(mActionEnable, QKeySequence(Qt::CTRL + Qt::Key_B));
+    actions->setDefaultShortcut(mActionEnable, QKeySequence(Qt::CTRL | Qt::Key_B));
     connect(mActionEnable, &QAction::triggered, this, &MainWindow::slotEnable);
 
-    action = new QAction(i18nc("@action", "Wake From Suspend..."), this);
+    QAction* action = new QAction(i18nc("@action", "Wake From Suspend..."), this);
     actions->addAction(QStringLiteral("wakeSuspend"), action);
     connect(action, &QAction::triggered, this, &MainWindow::slotWakeFromSuspend);
 
@@ -473,7 +458,7 @@ void MainWindow::initActions()
 
     mActionShowArchived = new KToggleAction(i18nc("@action", "Show Archi&ved Alarms"), this);
     actions->addAction(QStringLiteral("showArchivedAlarms"), mActionShowArchived);
-    actions->setDefaultShortcut(mActionShowArchived, QKeySequence(Qt::CTRL + Qt::Key_P));
+    actions->setDefaultShortcut(mActionShowArchived, QKeySequence(Qt::CTRL | Qt::Key_P));
     connect(mActionShowArchived, &KToggleAction::triggered, this, &MainWindow::slotShowArchived);
 
     mActionToggleTrayIcon = new KToggleAction(i18nc("@action", "Show in System &Tray"), this);
@@ -669,7 +654,7 @@ void MainWindow::slotNew(EditAlarmDlg::Type type)
 * Called when a template is selected from the New From Template popup menu.
 * Executes a New Alarm dialog, preset from the selected template.
 */
-void MainWindow::slotNewFromTemplate(const KAEvent* tmplate)
+void MainWindow::slotNewFromTemplate(const KAEvent& tmplate)
 {
     KAlarm::editNewAlarm(tmplate, mListView);
 }
@@ -682,7 +667,7 @@ void MainWindow::slotNewTemplate()
 {
     KAEvent event = mListView->selectedEvent();
     if (event.isValid())
-        KAlarm::editNewTemplate(&event, this);
+        KAlarm::editNewTemplate(event, this);
 }
 
 /******************************************************************************
@@ -693,7 +678,7 @@ void MainWindow::slotCopy()
 {
     KAEvent event = mListView->selectedEvent();
     if (event.isValid())
-        KAlarm::editNewAlarm(&event, this);
+        KAlarm::editNewAlarm(event, this);
 }
 
 /******************************************************************************
@@ -704,7 +689,7 @@ void MainWindow::slotModify()
 {
     KAEvent event = mListView->selectedEvent();
     if (event.isValid())
-        KAlarm::editAlarm(&event, this);   // edit alarm (view-only mode if archived or read-only)
+        KAlarm::editAlarm(event, this);   // edit alarm (view-only mode if archived or read-only)
 }
 
 /******************************************************************************
@@ -1252,7 +1237,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
                 event->addAlarm(alarm);
             }
             KAEvent ev(event);
-            KAlarm::editNewAlarm(&ev, win);
+            KAlarm::editNewAlarm(ev, win);
             return;
         }
         // If todos are included, use the first todo
@@ -1304,7 +1289,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
                     ev.setReminder(-offset / 60, false);
             }
             ev.endChanges();
-            KAlarm::editNewAlarm(&ev, win);
+            KAlarm::editNewAlarm(ev, win);
         }
         return;
     }
@@ -1541,7 +1526,7 @@ void MainWindow::editAlarm(EditAlarmDlg* dlg, const KAEvent& event)
 */
 void MainWindow::editAlarmOk()
 {
-    auto* dlg = qobject_cast<EditAlarmDlg*>(sender());
+    auto dlg = qobject_cast<EditAlarmDlg*>(sender());
     if (!dlg)
         return;
     QMap<EditAlarmDlg*, KAEvent>::Iterator it = mEditAlarmMap.find(dlg);
