@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -35,6 +35,7 @@
 #include "lib/locale.h"
 #include "lib/messagebox.h"
 #include "lib/radiobutton.h"
+#include "lib/slider.h"
 #include "lib/stackedwidgets.h"
 #include "lib/timeedit.h"
 #include "lib/timespinbox.h"
@@ -51,7 +52,6 @@ using namespace KHolidays;
 
 #include <KLocalizedString>
 #include <KShell>
-#include <KLineEdit>
 #include <KAboutData>
 #include <KStandardGuiItem>
 #include <QIcon>
@@ -76,6 +76,7 @@ using namespace KHolidays;
 #include <QStandardPaths>
 #include <QComboBox>
 #include <QLocale>
+#include <QLineEdit>
 
 using namespace KCalendarCore;
 using namespace KAlarmCal;
@@ -169,17 +170,17 @@ KAlarmPrefDlg::KAlarmPrefDlg()
     mEmailPageItem->setIcon(QIcon::fromTheme(QStringLiteral("internet-mail")));
     addPage(mEmailPageItem);
 
+    mEditPage = new EditPrefTab(mTabScrollGroup);
+    mEditPageItem = new KPageWidgetItem(mEditPage, i18nc("@title:tab", "Alarm Defaults"));
+    mEditPageItem->setHeader(i18nc("@title", "Default Alarm Edit Settings"));
+    mEditPageItem->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
+    addPage(mEditPageItem);
+
     mViewPage = new ViewPrefTab(mTabScrollGroup);
     mViewPageItem = new KPageWidgetItem(mViewPage, i18nc("@title:tab", "View"));
     mViewPageItem->setHeader(i18nc("@title", "View Settings"));
     mViewPageItem->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-theme")));
     addPage(mViewPageItem);
-
-    mEditPage = new EditPrefTab(mTabScrollGroup);
-    mEditPageItem = new KPageWidgetItem(mEditPage, i18nc("@title:tab", "Edit"));
-    mEditPageItem->setHeader(i18nc("@title", "Default Alarm Edit Settings"));
-    mEditPageItem->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
-    addPage(mEditPageItem);
     connect(button(QDialogButtonBox::Ok), &QAbstractButton::clicked, this, &KAlarmPrefDlg::slotOk);
     connect(button(QDialogButtonBox::Cancel), &QAbstractButton::clicked, this, &KAlarmPrefDlg::slotCancel);
     connect(button(QDialogButtonBox::Apply), &QAbstractButton::clicked, this, &KAlarmPrefDlg::slotApply);
@@ -434,7 +435,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
 {
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Run Mode"));
     topLayout()->addWidget(group);
-    auto* vlayout = new QVBoxLayout(group);
+    auto vlayout = new QVBoxLayout(group);
 
     // Start at login
     mAutoStart = new QCheckBox(i18nc("@option:check", "Start at login"), group);
@@ -451,7 +452,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     // Enable alarm names?
     QWidget* widget = new QWidget;  // this is for consistent left alignment
     topLayout()->addWidget(widget);
-    auto* hbox = new QHBoxLayout(widget);
+    auto hbox = new QHBoxLayout(widget);
     mUseAlarmNames = new QCheckBox(i18nc("@option:check", "Enable alarm names"));
     mUseAlarmNames->setMinimumSize(mUseAlarmNames->sizeHint());
     mUseAlarmNames->setWhatsThis(i18nc("@info:whatsthis", "Check to have the option to give alarms a name. This is a convenience to help you to identify alarms."));
@@ -486,7 +487,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Terminal for Command Alarms"));
     group->setWhatsThis(i18nc("@info:whatsthis", "Choose which application to use when a command alarm is executed in a terminal window"));
     topLayout()->addWidget(group);
-    auto* grid = new QGridLayout(group);
+    auto grid = new QGridLayout(group);
     int row = 0;
 
     mXtermType = new ButtonGroup(group);
@@ -498,7 +499,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
         const QStringList args = KShell::splitArgs(cmd);
         if (args.isEmpty()  ||  QStandardPaths::findExecutable(args[0]).isEmpty())
             continue;
-        auto* radio = new QRadioButton(args[0], group);
+        auto radio = new QRadioButton(args[0], group);
         radio->setMinimumSize(radio->sizeHint());
         mXtermType->addButton(radio, mXtermCount);
         if (mXtermFirst < 0)
@@ -515,7 +516,7 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     }
 
     // QHBox used here doesn't allow the QLineEdit to expand!?
-    auto* hlayout = new QHBoxLayout();
+    auto hlayout = new QHBoxLayout();
     grid->addLayout(hlayout, row + 1, 0, 1, 3, Qt::AlignLeft);
     QRadioButton* radio = new QRadioButton(i18nc("@option:radio Other terminal window command", "Other:"), group);
     hlayout->addWidget(radio);
@@ -640,13 +641,13 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     : PrefsTabBase(scrollGroup)
 {
     // Default time zone
-    auto* itemBox = new QHBoxLayout();
+    auto itemBox = new QHBoxLayout();
     itemBox->setContentsMargins(0, 0, 0, 0);
     topLayout()->addLayout(itemBox);
 
     QWidget* widget = new QWidget; // this is to control the QWhatsThis text display area
     itemBox->addWidget(widget);
-    auto* box =  new QHBoxLayout(widget);
+    auto box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     QLabel* label = new QLabel(i18nc("@label:listbox", "Time zone:"));
     box->addWidget(label);
@@ -724,7 +725,7 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
 
     QWidget* daybox = new QWidget(group);   // this is to control the QWhatsThis text display area
     layout->addWidget(daybox);
-    auto* wgrid = new QGridLayout(daybox);
+    auto wgrid = new QGridLayout(daybox);
     const QLocale locale;
     for (int i = 0;  i < 7;  ++i)
     {
@@ -851,7 +852,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     // Which resource to save to
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "New Alarms && Templates"));
     topLayout()->addWidget(group);
-    auto* bgroup = new QButtonGroup(group);
+    auto bgroup = new QButtonGroup(group);
     QBoxLayout* layout = new QVBoxLayout(group);
 
     mDefaultResource = new QRadioButton(i18nc("@option:radio", "Store in default calendar"), group);
@@ -868,7 +869,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     // Archived alarms
     group = new QGroupBox(i18nc("@title:group", "Archived Alarms"));
     topLayout()->addWidget(group);
-    auto* grid = new QGridLayout(group);
+    auto grid = new QGridLayout(group);
     grid->setColumnStretch(1, 1);
     grid->setColumnMinimumWidth(0, gridIndentWidth());
     mKeepArchived = new QCheckBox(i18nc("@option:check", "Keep alarms after expiry"), group);
@@ -878,7 +879,7 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     grid->addWidget(mKeepArchived, 0, 0, 1, 2, Qt::AlignLeft);
 
     QWidget* widget = new QWidget;
-    auto* box = new QHBoxLayout(widget);
+    auto box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     mPurgeArchived = new QCheckBox(i18nc("@option:check", "Discard archived alarms after:"));
     mPurgeArchived->setMinimumSize(mPurgeArchived->sizeHint());
@@ -980,7 +981,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
 {
     QWidget* widget = new QWidget;
     topLayout()->addWidget(widget);
-    auto* box = new QHBoxLayout(widget);
+    auto box = new QHBoxLayout(widget);
     box->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     QLabel* label = new QLabel(i18nc("@label", "Email client:"));
     box->addWidget(label);
@@ -1024,7 +1025,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     // Your Email Address group box
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Your Email Address"));
     topLayout()->addWidget(group);
-    auto* grid = new QGridLayout(group);
+    auto grid = new QGridLayout(group);
     grid->setColumnStretch(2, 1);
 
     // 'From' email address controls ...
@@ -1208,25 +1209,25 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
 
     mTabs = new QTabWidget();
     topLayout()->addWidget(mTabs);
-    auto* tabgroup = new StackedGroupT<QWidget>(mTabs);
+    auto tabgroup = new StackedGroupT<QWidget>(mTabs);
 
-    auto* topGeneral = new StackedWidgetT<QWidget>(tabgroup);
-    auto* tgLayout = new QVBoxLayout(topGeneral);
+    auto topGeneral = new StackedWidgetT<QWidget>(tabgroup);
+    auto tgLayout = new QVBoxLayout(topGeneral);
     mTabGeneral = mTabs->addTab(topGeneral, i18nc("@title:tab", "General"));
 
-    auto* topTypes = new StackedWidgetT<QWidget>(tabgroup);
-    auto* ttLayout = new QVBoxLayout(topTypes);
-    mTabTypes = mTabs->addTab(topTypes, i18nc("@title:tab", "Alarm Types"));
+    auto topTypes = new StackedWidgetT<QWidget>(tabgroup);
+    auto ttLayout = new QVBoxLayout(topTypes);
+    mTabTypes = mTabs->addTab(topTypes, i18nc("@title:tab Settings specific to alarm type", "Type Specific"));
 
-    auto* topFontColour = new StackedWidgetT<QWidget>(tabgroup);
-    auto* tfLayout = new QVBoxLayout(topFontColour);
+    auto topFontColour = new StackedWidgetT<QWidget>(tabgroup);
+    auto tfLayout = new QVBoxLayout(topFontColour);
     mTabFontColour = mTabs->addTab(topFontColour, i18nc("@title:tab", "Font && Color"));
 
     // MISCELLANEOUS
     // Alarm message display method
     QWidget* widget = new QWidget;   // this is to control the QWhatsThis text display area
     tgLayout->addWidget(widget);
-    auto* box = new QHBoxLayout(widget);
+    auto box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     QLabel* label = new QLabel(EditDisplayAlarmDlg::i18n_lbl_DisplayMethod());
     box->addWidget(label);
@@ -1278,7 +1279,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     // How to handle February 29th in yearly recurrences
     QWidget* febBox = new QWidget;  // this is to control the QWhatsThis text display area
     tgLayout->addWidget(febBox);
-    auto* vbox = new QVBoxLayout(febBox);
+    auto vbox = new QVBoxLayout(febBox);
     vbox->setContentsMargins(0, 0, 0, 0);
     label = new QLabel(i18nc("@label", "In non-leap years, repeat yearly February 29th alarms on:"));
     label->setAlignment(Qt::AlignLeft);
@@ -1313,7 +1314,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     // DISPLAY ALARMS
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Display Alarms"));
     ttLayout->addWidget(group);
-    auto* vlayout = new QVBoxLayout(group);
+    auto vlayout = new QVBoxLayout(group);
 
     mConfirmAck = new QCheckBox(EditDisplayAlarmDlg::i18n_chk_ConfirmAck());
     mConfirmAck->setMinimumSize(mConfirmAck->sizeHint());
@@ -1346,7 +1347,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     ttLayout->addWidget(bbox);
     vlayout = new QVBoxLayout(bbox);
 
-    auto* hlayout = new QHBoxLayout;
+    auto hlayout = new QHBoxLayout;
     hlayout->setContentsMargins(0, 0, 0, 0);
     vlayout->addLayout(hlayout);
     mSound = new QComboBox();
@@ -1381,6 +1382,25 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     widget->setWhatsThis(i18nc("@info:whatsthis", "Enter the default sound file to use in the alarm edit dialog."));
     vlayout->addWidget(widget);
 
+    box = new QHBoxLayout();
+    box->setContentsMargins(0, 0, 0, 0);
+    mSoundVolumeCheckbox = new CheckBox(SoundWidget::i18n_chk_SetVolume(), nullptr);
+    connect(mSoundVolumeCheckbox, &CheckBox::toggled, this, [this](bool on) { mSoundVolumeSlider->setEnabled(on); });
+    box->addWidget(mSoundVolumeCheckbox);
+    mSoundVolumeSlider = new Slider(0, 100, 10, Qt::Horizontal);
+    mSoundVolumeCheckbox->setWhatsThis(i18nc("@info:whatsthis", "Select to set the default volume for sound files in the alarm edit dialog."));
+    mSoundVolumeSlider->setTickPosition(QSlider::TicksBelow);
+    mSoundVolumeSlider->setTickInterval(10);
+    mSoundVolumeSlider->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed));
+    mSoundVolumeSlider->setWhatsThis(i18nc("@info:whatsthis", "The default volume for sound files in the alarm edit dialog."));
+    mSoundVolumeSlider->setEnabled(false);
+    box->addWidget(mSoundVolumeSlider);
+    label = new QLabel;
+    mSoundVolumeSlider->setValueLabel(label, QStringLiteral("%1%"), true);
+    box->addWidget(label);
+    mSoundVolumeCheckbox->setFocusWidget(mSoundVolumeSlider);
+    vlayout->addLayout(box);
+
     // COMMAND ALARMS
     group = new QGroupBox(i18nc("@title:group", "Command Alarms"));
     ttLayout->addWidget(group);
@@ -1465,6 +1485,9 @@ void EditPrefTab::restore(bool, bool allTabs)
         mSound->setCurrentIndex(soundIndex(Preferences::defaultSoundType()));
         mSoundFile->setText(Preferences::defaultSoundFile());
         mSoundRepeat->setChecked(Preferences::defaultSoundRepeat());
+        const int volume = Preferences::defaultSoundVolume() * 100;
+        mSoundVolumeCheckbox->setChecked(volume >= 0);
+        mSoundVolumeSlider->setValue(volume >= 0 ? volume : 100);
         mCmdScript->setChecked(Preferences::defaultCmdScript());
         mCmdXterm->setChecked(Preferences::defaultCmdLogType() == Preferences::Log_Terminal);
         mEmailBcc->setChecked(Preferences::defaultEmailBcc());
@@ -1529,6 +1552,9 @@ void EditPrefTab::apply(bool syncToDisc)
     b = mSoundRepeat->isChecked();
     if (b != Preferences::defaultSoundRepeat())
         Preferences::setDefaultSoundRepeat(b);
+    const float v = mSoundVolumeCheckbox->isChecked() ? (float)mSoundVolumeSlider->value() / 100 : -1;
+    if (v != Preferences::defaultSoundVolume())
+        Preferences::setDefaultSoundVolume(v);
     b = mCmdScript->isChecked();
     if (b != Preferences::defaultCmdScript())
         Preferences::setDefaultCmdScript(b);
@@ -1627,11 +1653,11 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     topLayout()->addWidget(mTabs);
 
     QWidget* widget = new QWidget;
-    auto* topGeneral = new QVBoxLayout(widget);
+    auto topGeneral = new QVBoxLayout(widget);
     mTabGeneral = mTabs->addTab(widget, i18nc("@title:tab", "General"));
 
     widget =  new QWidget;
-    auto* topWindows = new QVBoxLayout(widget);
+    auto topWindows = new QVBoxLayout(widget);
     mTabWindows = mTabs->addTab(widget, i18nc("@title:tab", "Alarm Windows"));
 
     // Run-in-system-tray check box or group.
@@ -1646,7 +1672,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
         // icons, so don't show options to hide the system tray icon.
         widget = new QWidget;  // this is to allow left adjustment
         topGeneral->addWidget(widget);
-        auto* box = new QHBoxLayout(widget);
+        auto box = new QHBoxLayout(widget);
         mShowInSystemTrayCheck = new QCheckBox(showInSysTrayText);
         mShowInSystemTrayCheck->setWhatsThis(showInSysTrayWhatsThis);
         box->addWidget(mShowInSystemTrayCheck);
@@ -1659,7 +1685,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
         mShowInSystemTrayGroup->setCheckable(true);
         mShowInSystemTrayGroup->setWhatsThis(showInSysTrayWhatsThis);
         topGeneral->addWidget(mShowInSystemTrayGroup);
-        auto* grid = new QGridLayout(mShowInSystemTrayGroup);
+        auto grid = new QGridLayout(mShowInSystemTrayGroup);
         grid->setColumnStretch(1, 1);
         grid->setColumnMinimumWidth(0, gridIndentWidth());
 
@@ -1701,7 +1727,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     // System tray tooltip group box
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "System Tray Tooltip"));
     topGeneral->addWidget(group);
-    auto* grid = new QGridLayout(group);
+    auto grid = new QGridLayout(group);
     grid->setColumnStretch(2, 1);
     grid->setColumnMinimumWidth(0, gridIndentWidth());
     grid->setColumnMinimumWidth(1, gridIndentWidth());
@@ -1714,7 +1740,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     grid->addWidget(mTooltipShowAlarms, 0, 0, 1, 3, Qt::AlignLeft);
 
     widget = new QWidget;
-    auto* box = new QHBoxLayout(widget);
+    auto box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
     mTooltipMaxAlarms = new QCheckBox(i18nc("@option:check", "Maximum number of alarms to show:"));
     mTooltipMaxAlarms->setMinimumSize(mTooltipMaxAlarms->sizeHint());
@@ -1755,8 +1781,8 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
 
     group = new QGroupBox(i18nc("@title:group", "Alarm List"));
     topGeneral->addWidget(group);
-    auto* hlayout = new QHBoxLayout(group);
-    auto* colourLayout = new QVBoxLayout();
+    auto hlayout = new QHBoxLayout(group);
+    auto colourLayout = new QVBoxLayout();
     colourLayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(colourLayout);
 
