@@ -116,7 +116,7 @@ public:
     template <class DataModel>
     static AlarmListModel* create(QObject* parent = nullptr);
 
-    ~AlarmListModel();
+    ~AlarmListModel() override;
 
     /** Return the model containing all active and archived alarms. */
     template <class DataModel>
@@ -170,7 +170,7 @@ public:
     template <class DataModel>
     static TemplateListModel* create(QObject* parent = nullptr);
 
-    ~TemplateListModel();
+    ~TemplateListModel() override;
 
     /** Return the model containing all alarm templates. */
     template <class DataModel>
@@ -213,7 +213,7 @@ private:
 template <class DataModel>
 EventListModel* EventListModel::create(CalEvent::Types types, QObject* parent)
 {
-    auto* model = new EventListModel(types, parent);
+    auto model = new EventListModel(types, parent);
     model->initialise<DataModel>();
     return model;
 }
@@ -229,7 +229,7 @@ template <class DataModel> void EventListModel::initialise()
 template <class DataModel>
 AlarmListModel* AlarmListModel::create(QObject* parent)
 {
-    auto* model = new AlarmListModel(parent);
+    auto model = new AlarmListModel(parent);
     model->EventListModel::initialise<DataModel>();
     return model;
 }
@@ -248,7 +248,7 @@ AlarmListModel* AlarmListModel::all()
 template <class DataModel>
 TemplateListModel* TemplateListModel::create(QObject* parent)
 {
-    auto* model = new TemplateListModel(parent);
+    auto model = new TemplateListModel(parent);
     model->EventListModel::initialise<DataModel>();
     return model;
 }
