@@ -20,7 +20,7 @@
 TemplateMenuAction::TemplateMenuAction(const QIcon& icon, const QString& label, QObject* parent)
     : KActionMenu(icon, label, parent)
 {
-    setDelayed(false);
+    setPopupMode(QToolButton::InstantPopup);
     connect(menu(), &QMenu::aboutToShow, this, &TemplateMenuAction::slotInitMenu);
     connect(menu(), &QMenu::triggered, this, &TemplateMenuAction::slotSelected);
 }
@@ -65,8 +65,8 @@ void TemplateMenuAction::slotSelected(QAction* action)
     if (it == mOriginalTexts.constEnd()  ||  it.value().isEmpty())
         return;
     KAEvent templ = ResourcesCalendar::templateEvent(it.value());
-    templ.setName(QString());
-    Q_EMIT selected(templ.isValid() ? &templ : nullptr);
+    templ.setName(QString());   // don't preset the new alarm with the template's name
+    Q_EMIT selected(templ);
 }
 
 // vim: et sw=4:
